Learn R Programming

deltaGseg (version 1.12.2)

chooseBreaks: Choose a given number of breakpoints in a set of trajectories.

Description

This function automatically chooses a subset of breakpoints from all the estimated breakpoints of function splitTraj

Usage

chooseBreaks(breakpoints, numbreaks)

Arguments

breakpoints
Numeric list, output from splitTraj.
numbreaks
Integer. Number of breakpoints to be returned per trajectory. Breakpoints chosen will be evenly spaced from those defined by splitTraj.

Value

  • Returns a numeric list of breakpoints, one list per trajectory.

Details

None.

See Also

splitTraj

Examples

Run this code
data(deltaGseg)
all_breakpoints<-splitTraj(traj1) #default splits=15 (i.e. 16 segments).
all_breakpoints
chooseBreaks(all_breakpoints,numbreaks=3)

Run the code above in your browser using DataLab