Learn R Programming

deltaGseg (version 1.12.2)

clusterPV: clusterPV

Description

Wrapper for modified pvclust function.

Usage

clusterPV(object,bootstrap=500)

Arguments

object
An object of class 'SegTrajectories'.
bootstrap
Integer. Number of bootstraps to run.

Value

  • Returns an object of class "pvclust". For use in clusterSegments when running the pvclust option.

Details

This is a wrapper to call the pvclust function that has been modified to suit our deltaGseg computation.

References

Shimodaira, H. (2004). Approximately unbiased tests of regions using multistep-multiscale bootstrap resampling, Annals of Statistics 32, 2616-2641.

See Also

clusterSegments]

Examples

Run this code
data(deltaGseg)
clusterPV(traj1.denoise)

Run the code above in your browser using DataLab